ntrfc.filehandling package
==========================

Submodules
----------

ntrfc.filehandling.datafiles module
-----------------------------------

.. automodule:: ntrfc.filehandling.datafiles
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.filehandling.mesh module
------------------------------

.. automodule:: ntrfc.filehandling.mesh
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ntrfc.filehandling
   :members:
   :undoc-members:
   :show-inheritance:
